@@ -26,11 +26,12 @@ def main():
     parser.add_argument("-D", "--delete-them", help="Whenever a file is found with identical contents to a previously discovered file, delete the new one.  This option is dangerous.", action='store_true')
     parser.add_argument("-m", "--min-size", help="Ignore files smaller than this (default %d)." % DEFAULT_MINSIZE, default=DEFAULT_MINSIZE, type=int, metavar='M')
     parser.add_argument("-p", "--profiles", help="Generate a profile of your files which doesn't contain very much potentially-sensitive information (it contains only the file sizes, how many files were duplicates, and an 8-bit checksum of the first 8192 bytes of each file).  This could be useful for a p2p storage project to measure how valuable convergent encryption is.", default=DEFAULT_PROFILES, action='store_true')
+    parser.add_argument("dir", nargs='*', help="a directory to recursively examine", default=".")
     args = parser.parse_args()
 
     if args.delete_them and args.hard_link_them:
         print "Please choose only one of .--hard-link_them. and '--delete-them'."
         sys.exit(-1)
 
-    return dupfilefind.dffem(len(args.verbose), args.ignore_dirs, args.hard_link_them, args.delete_them, args.min_size, args.profiles)
+    return dupfilefind.dffem(len(args.verbose), args.ignore_dirs, args.hard_link_them, args.delete_them, args.min_size, args.profiles, args.dir)
 
