@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-import md5, os, stat, zlib
+import md5, os, stat
 
 READSIZE=8192
 
@@ -12,20 +12,14 @@ def md5it(f):
         d = f.read(READSIZE)
     return h.hexdigest()
 
-def headadler8bit(f):
-    adlerval = 0
-    data = f.read(READSIZE)
-    adlerval = zlib.adler32(data, adlerval)
-    return adlerval % 256
-
-def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES):
+def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, DIRS):
     assert not (HARDLINKEM and DELETEEM) # at most one of these
     # d1 = { k: size, v: { k: (dev, ino,), v: [ fname ] } }
     d1 = {}
 
     visiteddirs = set() # to avoid symlink recursion
 
-    # First pass: build map from size, dev, inode number to filenames, and if PROFILES then print out the headadler8bit and size of each file.
+    # First pass: build map from size, dev, inode number to filenames, and if PROFILES then print out the first 2 chars of the md5sum and size of each file.
     def visit(dirpath, dirnames, fnames):
         if dirpath in visiteddirs:
             return
@@ -47,7 +41,7 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES):
                         l = []
                         d2[(thestat.st_dev, thestat.st_ino,)] = l
                         if PROFILES:
-                            print "%02x %s" % (headadler8bit(open(fullfname, 'r')), thestat.st_size)
+                            print "%s:%s" % (md5it(open(fullfname, 'r'))[:2], thestat.st_size)
                     l.append(fullfname)
             except EnvironmentError, le:
                 if VERBOSITY:
@@ -59,8 +53,9 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES):
                 for (idirpath, idirnames, ifnames,) in os.walk(dirname):
                     visit(idirpath, idirnames, ifnames)
 
-    for (dirpath, dirnames, fnames,) in os.walk("."):
-        visit(dirpath, dirnames, fnames)
+    for DIR in DIRS:
+        for (dirpath, dirnames, fnames,) in os.walk(DIR):
+            visit(dirpath, dirnames, fnames)
 
     # Second pass: for any files which have identical size and different (dev, ino,), md5 that file.  Build map from md5 to { (dev, ino,): [ fname ] }.
     # ... and print out any collisions (that is: same md5, different (dev, ino,)).
@@ -94,7 +89,7 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES):
                         onename = d4.items()[0][1][0]
                     for ((iterdev, iterino,), iterfnames,) in d4.iteritems():
                         if PROFILES:
-                            print "identical; headadler8bit: %02x, dev: %s, ino: %s, size: %s" % (headadler8bit(open(onename, 'r')), iterdev, iterino, size,)
+                            print "identical; md5: %s, dev: %s, ino: %s, size: %s" % (md5it(open(onename, 'r'))[:2], iterdev, iterino, size,)
                         else:
                             print "md5: %s, dev: %s, ino: %s, size: %s, fnames: %s" % (md5h, iterdev, iterino, size, iterfnames,)
                         if HARDLINKEM or DELETEEM:
@@ -109,7 +104,7 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES):
                 elif len(d4) > 2:
                     # More collisions.  Print out the new one.
                     if PROFILES:
-                        print "identical; headadler8bit: %02x, dev: %s, ino: %s, size: %s" % (headadler8bit(open(fnames[0], 'r')), dev, ino, size,)
+                        print "identical; md5: %s, dev: %s, ino: %s, size: %s" % (md5it(open(fnames[0], 'r'))[:2], dev, ino, size,)
                     else:
                         print "md5: %s, dev: %s, ino: %s, size: %s, fnames: %s" % (md5h, dev, ino, size, fnames,)
                     if HARDLINKEM or DELETEEM:
